#include "ExportParameters.h"
#include "dialog.h"

ExporterDialog::ExporterDialog(BaseDocument* doc)
{
    active_document=doc;
    parameters.exportAllObjects=FALSE;
    n_selected_object=0;
    parameters.object=doc->GetFirstObject();

    // Load the preferences file if exists (for the converter file name)
    Filename preferencesFname=GeGetPluginPath();
    #ifndef C4D_R9
    preferencesFname.SetFile(Filename("preferences.txt"));
    #else
    preferencesFname.SetFile("preferences.txt");
    #endif
    if(GeFExist(preferencesFname,FALSE))
    {
        BaseFile* file=BaseFile::Alloc();
        file->Open(preferencesFname,GE_READ,FILE_DIALOG,GeGetByteOrder());
        String converter_name;
        file->ReadString(&converter_name);
        parameters.converterFname.SetString(converter_name);
        file->Close();
        BaseFile::Free(file);
    }
    Open();
}



Bool ExporterDialog::CreateLayout()
{
    SetTitle("Ogre3D Exporter");

    parameters.noObjects=TRUE;
    if(parameters.object)
    {
        // Object list creation
        AddStaticText(0,BFH_CENTER|BFV_TOP,0,0,"Object(s) to export",BORDER_GROUP_IN);
        AddComboBox(11000,0,0,0);
        INT t=1;
        do
        {
            if(parameters.object->GetType()==Opolygon || parameters.object->GetType()==Onull)
            {
                parameters.noObjects=FALSE;
                AddChild(11000,t,parameters.object->GetName());
            }
            parameters.object=parameters.object->GetNext();
            t++;
        }
        while(parameters.object);

        if(parameters.noObjects)
            Close(FALSE);

        // Dialog creation
        AddCheckbox(11020,BFH_SCALEFIT,0,0,"Export all objects");

        AddSeparatorH(BFH_SCALEFIT);

        AddStaticText(0,BFH_CENTER,0,0,"Options",BORDER_GROUP_IN);

        AddCheckbox(11030,BFH_SCALEFIT,0,0,"Export UV coordinates");
        AddCheckbox(11040,BFH_SCALEFIT,0,0,"Export normals");

        AddCheckbox(11050,BFH_SCALEFIT,0,0,"Export skeleton");
        GroupBegin(11051,BFH_LEFT,2,0,"",0);
        AddStaticText(11052,BFH_LEFT,0,0,"Animation name ",0);
        AddEditText(11053,0,150,10);
        GroupEnd();
        GroupBegin(11054,BFH_LEFT,2,0,"",0);
        AddStaticText(11055,BFH_LEFT,0,0,"Start frame ",0);
        AddEditNumber(11056,0,50,10);
        GroupEnd();
        GroupBegin(11057,BFH_LEFT,2,0,"",0);
        AddStaticText(11058,BFH_LEFT,0,0,"End frame ",0);
        AddEditNumber(11059,0,50,10);
        GroupEnd();

        AddCheckbox(11060,BFH_SCALEFIT,0,0,"Include material name");

        GroupBegin(11070,BFH_SCALEFIT,2,0,"",0);
        AddCheckbox(11071,BFH_SCALEFIT,0,0,"Convert XML files");
        AddButton(11072,BFH_SCALEFIT,0,0,"Locate converter...");
        GroupEnd();

        AddSeparatorH(BFH_SCALEFIT);
        GroupBegin(11010,BFH_SCALEFIT,2,0,"",0);
        AddButton(11011,BFH_SCALEFIT,0,0,"OK");
        AddButton(11012,BFH_SCALEFIT,0,0,"Cancel");
        GroupEnd();

        AddStaticText(0,BFH_CENTER|BFV_BOTTOM,0,0,"Ogre3D Exporter for Cinema4D - Pascal Prat (aka Licorna)",BORDER_GROUP_TOP);
    }
    else
    {
        parameters.noObjects=TRUE;
        Close(FALSE);
    }
    return TRUE;
}

Bool ExporterDialog::InitValues()
{
    SetBool(11020,FALSE);
    SetBool(11030,FALSE);
    SetBool(11040,TRUE);
    SetBool(11050,TRUE);
    SetBool(11060,FALSE);
    SetBool(11071,TRUE);
    Enable(11011,FALSE);
    SetString(11053,"anim");
    SetReal(11056,0.0,0.0,active_document->GetMaxTime().GetFrame(active_document->GetFps()),1.0,FORMAT_LONG);
    SetReal(11059,active_document->GetMaxTime().GetFrame(active_document->GetFps()),0.0,active_document->GetMaxTime().GetFrame(active_document->GetFps()),1.0,FORMAT_LONG);
    return TRUE;
}

Bool ExporterDialog::Command(LONG id,const BaseContainer& msg)
{
    // Get combobox state
    if(id==11000)
        GetLong(11000,n_selected_object);

    // Get checkboxes state
    GetBool(11020,parameters.exportAllObjects);
    Enable(11000,!parameters.exportAllObjects);

    GetBool(11030,parameters.exportUV);
    GetBool(11040,parameters.exportNormals);

    GetBool(11050,parameters.exportSkeleton);
    Enable(11052,parameters.exportSkeleton);
    Enable(11053,parameters.exportSkeleton);
    Enable(11055,parameters.exportSkeleton);
    Enable(11056,parameters.exportSkeleton);
    Enable(11058,parameters.exportSkeleton);
    Enable(11059,parameters.exportSkeleton);

    GetBool(11060,parameters.includeMaterialName);
    GetBool(11071,parameters.convertXML);

    if(n_selected_object==0 && !parameters.exportAllObjects)
        Enable(11011,FALSE);
    else
        Enable(11011,TRUE);

    // Set converter location and write it to preferences file
    if(id==11072)
    {
        String title="Select the XML converter";
        if(parameters.converterFname.FileSelect(FSTYPE_ANYTHING,0,&title))
        {
            Filename preferencesFname=GeGetPluginPath();
            #ifndef C4D_R9
            preferencesFname.SetFile(Filename("preferences.txt"));
            #else
            preferencesFname.SetFile("preferences.txt");
            #endif

            if(GeFExist(preferencesFname,FALSE))
                GeFKill(preferencesFname,FALSE);
            BaseFile* file=BaseFile::Alloc();
            file->Open(preferencesFname,GE_WRITE,FILE_DIALOG,GeGetByteOrder());
            file->WriteString(parameters.converterFname.GetString());
            file->Close();
            BaseFile::Free(file);
        }
    }

    // OK button
    if(id==11011)
    {
        if(!parameters.exportAllObjects)
        {
            parameters.object=active_document->GetFirstObject();
            INT t;
            for(t=1;t<n_selected_object;t++)
                parameters.object=parameters.object->GetNext();    // Get selected object
        }
        if(parameters.exportSkeleton)
        {
            GetString(11053,parameters.animationName);
            GetReal(11056,parameters.firstFrame);
            GetReal(11059,parameters.lastFrame);
            if(parameters.firstFrame>=parameters.lastFrame)
            {
                parameters.firstFrame=0;
                parameters.lastFrame=active_document->GetMaxTime().GetFrame(active_document->GetFps());
            }
        }
        GePrint("ok");
        Close(TRUE);
    }

    // Cancel button
    if(id==11012)
    {
        parameters.cancel=TRUE;
        Close(FALSE);
    }
    return TRUE;
}
