#include <c4d.h>

// A class for representing a bone in a skeleton hierarchy
class SkeletonElement
{
private:
    BaseObject* _bone;
    SkeletonElement* _next_skeleton_element;
    SkeletonElement* _child_skeleton_element;
    SkeletonElement* _parent_skeleton_element;
    INT _index;

public:
    SkeletonElement(BaseObject* bone);

    BaseObject* GetBone();

    SkeletonElement* GetNextSkeletonElement();
    SkeletonElement* GetChildSkeletonElement();
    SkeletonElement* GetParentSkeletonElement();
    INT GetIndex();

    void SetNextSkeletonElement(SkeletonElement* skeleton_element);
    void SetChildSkeletonElement(SkeletonElement* skeleton_element);
    void SetParentSkeletonElement(SkeletonElement* skeleton_element);
    void SetIndex(INT index);
};


// A class for representing skeletons
class Skeleton
{
private:
    SkeletonElement* _first_skeleton_element;
    SkeletonElement* _current_skeleton_element;
    INT _n_bones;
public:
    Skeleton(BaseObject* object);
    ~Skeleton();

    SkeletonElement* GetFirstSkeletonElement();
    SkeletonElement* GetCurrentSkeletonElement();

    INT GetSkeletonElementNumber();

    // Functions for moving in the bones hierarchy
    void ToFirstSkeletonElement();
    void ToNextSkeletonElement();
    void ToChildSkeletonElement();
    void ToParentSkeletonElement();
    void ToIndex(INT index);

    // Functions for adding bones
    void InsertSkeletonElement(BaseObject* bone);
    void InsertChildSkeletonElement(BaseObject* child_bone,SkeletonElement* parent_skeleton_element);

    void GetObjectSkeleton(BaseObject* object); // Retrieve the whole bone hierarchy of an object
};
